
// Persistence of Vision Ray Tracer Scene Description File
// File: link1.pov
// Vers: 3
// Desc: demonstration of single chain
// Date: 02/19/97
// Auth: Rob Antonishen
//

#version 3

#include "colors.inc"

global_settings
{
  assumed_gamma 1.0
}

// ----------------------------------------
camera
{
  location  <0.0, 1, -3>
  direction 1.5*z
  right     4/3*x
  look_at   <0.0, 0.5,  0.0>
}

sky_sphere
{
  pigment
  {
    gradient y
    color_map { [0.0 color blue 0.6] [1.0 color rgb 1] }
  }
}

light_source
{
  0*x // light's position (translated below)
  color red 1.0  green 1.0  blue 1.0  // light's color
  translate <-30, 30, -30>
}

// ----------------------------------------
plane { y, -1 pigment {color rgb <0.7,0.5,0.3>}}

// texture stolen from the chain tutorial in the docs
#declare Chain_Gold = texture {
  pigment { BrightGold }
  finish {
    ambient .1
    diffuse .4
    reflection .25
    specular 1
    metallic
  }
}

#declare link_thick = 0.1 //  rad
#declare link_width = 0.4  //  rad
#declare half_torus = intersection {
  // torus {MAJOR, MINOR} // (in the X-Z plane)
  // MAJOR = float value giving the major radius
  // MINOR = float specifying the minor radius
  // The major radius extends from the center of the hole
  // to the mid-line of the rim while the minor radius
  // is the radius of the cross-section of the rim.
  torus { link_width,link_thick }
  plane { x,0 }
  translate x*(link_width-link_thick)
}
#declare cyl_link = cylinder {
  <link_width-link_thick,0,0>,<1-(link_width-link_thick),0,0>, link_thick
}

#declare link = union {
  object { half_torus }
  object { half_torus scale <-1,1,1> translate x*1 }
  object { cyl_link translate z*link_width }
  object { cyl_link translate -z*link_width }
  rotate x*0
  texture { Chain_Gold }
  translate x*-0.5
  scale 2
  translate x*0.5
}


#declare link_length = 0.2
#declare link_rotation = 46 // rotations slightly off of even values are more interesting
#declare link_error = 0.01 // (fraction of link_length)
#declare chain_start=<-1,1,0>
#declare chain_end=<1,1,0>
#declare chain_scale=1      // chain scale
// #declare chain_debug=on

#include "chain11.inc"
