// Persistence of Vision Ray Tracer Scene Description File
// File: one_link.pov
// Vers: 3
// Desc: renders one link so you can see if it line up right.
// Date: 02/11/96
// Auth: Rob Antonishen
//

#version 3

#include "colors.inc"

global_settings
{
  assumed_gamma 1.0
}

// ----------------------------------------
camera
{
  location  <0.5, 0, -2>
  direction 1.5*z
  right     4/3*x
  look_at   <0.5, 0, 0>
  orthographic
}


light_source
{
  0*x // light's position (translated below)
  color red 1.0  green 1.0  blue 1.0  // light's color
  translate <-30, 30, -30>
}


// ----------------------------------------
// unit grid
plane { -z, 2
  texture {
    pigment {
      gradient x       //this is the PATTERN_TYPE
      color_map {
        [0.00  color rgbf <1,1,1,1> ]
        [0.99  color rgbf <1,1,1,1> ]
        [0.99  color rgbf <0,0,1,0> ]
      }
    }
    finish { ambient 1.0 }
  }
  texture {
    pigment {
      gradient y       //this is the PATTERN_TYPE
      color_map {
        [0.00  color rgbf <1,1,1,1> ]
        [0.99  color rgbf <1,1,1,1> ]
        [0.99  color rgbf <0,0,1,0> ]
      }
    }
    finish { ambient 1.0 }
  }
  translate <5,5,0>
  no_shadow
}
  


// Sample Link
#declare link_thick = 0.1 //  rad
#declare link_width = 0.4  //  rad
#declare half_torus = intersection {
  // torus {MAJOR, MINOR} // (in the X-Z plane)
  // MAJOR = float value giving the major radius
  // MINOR = float specifying the minor radius
  // The major radius extends from the center of the hole
  // to the mid-line of the rim while the minor radius
  // is the radius of the cross-section of the rim.
  torus { link_width,link_thick }
  plane { x,0 }
  translate x*(link_width-link_thick)
}
#declare cyl_link = cylinder {
  <link_width-link_thick,0,0>,<1-(link_width-link_thick),0,0>, link_thick
}

#declare link = union {
  object { half_torus }
  object { half_torus scale <-1,1,1> translate x*1 }
  object { cyl_link translate z*link_width }
  object { cyl_link translate -z*link_width }
  rotate x*90
  pigment { White }
}

object { link }
